######################################
Signal Processing (:mod:`gwpy.signal`)
######################################

.. automodule:: gwpy.signal

.. seealso::

    - **User Guide**: :doc:`/signal/index`
    - **Examples**: :doc:`/examples/signal/index`

.. automodapi:: gwpy.signal
    :include-all-objects:
    :no-heading:
    :no-main-docstr:

----

.. toctree::
    :caption: Submodules
    :maxdepth: 1

    gwpy.signal.filter_design
    gwpy.signal.window
    gwpy.signal.spectral
    gwpy.signal.qtransform
